summaryrefslogtreecommitdiffstats
path: root/host/include
diff options
context:
space:
mode:
Diffstat (limited to 'host/include')
-rw-r--r--host/include/uhd/transport/usb_device_handle.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/host/include/uhd/transport/usb_device_handle.hpp b/host/include/uhd/transport/usb_device_handle.hpp
index 78c78f6b5..c3eb72b00 100644
--- a/host/include/uhd/transport/usb_device_handle.hpp
+++ b/host/include/uhd/transport/usb_device_handle.hpp
@@ -68,9 +68,9 @@ public:
/*!
* Return a vector of USB devices on this host
* \return a vector of USB device handles
*/
- static UHD_API std::vector<usb_device_handle::sptr> get_device_list();
+ static UHD_API std::vector<usb_device_handle::sptr> get_device_list(boost::uint16_t vid, boost::uint16_t pid);
}; //namespace usb
@@ -68,9 +68,9 @@ public:
/*!
* Return a vector of USB devices on this host
- * \return a vector of USB device handles
+ * \return a vector of USB device handles that match vid and pid
*/